# AWS PDK

All documentation is located at: https://aws.github.io/aws-pdk

# aws-arch

Please refer to [Developer Guide](./docs/developer_guides/aws-arch/index.md).

# cdk-graph

Please refer to [Developer Guide](./docs/developer_guides/cdk-graph/index.md).

# cdk-graph-plugin-diagram

Please refer to [Developer Guide](./docs/developer_guides/cdk-graph-plugin-diagram/index.md).

# cdk-graph-plugin-threat-composer

Please refer to [Developer Guide](./docs/developer_guides/cdk-graph-plugin-threat-composer/index.md).

# cloudscape-react-ts-website

Please refer to [Developer Guide](./docs/developer_guides/cloudscape-react-ts-website/index.md).

# identity

Please refer to [Developer Guide](./docs/developer_guides/identity/index.md).

# infrastructure

Please refer to [Developer Guide](./docs/developer_guides/infrastructure/index.md).

# monorepo

Please refer to [Developer Guide](./docs/developer_guides/monorepo/index.md).

# pdk-nag

Please refer to [Developer Guide](./docs/developer_guides/pdk-nag/index.md).

# pipeline

Please refer to [Developer Guide](./docs/developer_guides/pipeline/index.md).

# static-website

Please refer to [Developer Guide](./docs/developer_guides/static-website/index.md).

# type-safe-api

Please refer to [Developer Guide](./docs/developer_guides/type-safe-api/index.md).
